@@ -113,7 +113,7 @@ static gchar *compute_hypothetical_replacement (const gchar *value)
 
     Makes sure that there will be no...
     1. ...values for the "enabled" option other than "yes" and "no"...
-    2. ...double menu IDs...
+    2. ...duplicate menu IDs...
     3. ...empty (pipe) menu labels...
     ...after a find and replace.
 
@@ -164,7 +164,7 @@ static gboolean validity_check (              GtkTreeModel *model,
         }
     }
 
-    // Make sure that there will be no double menu IDs after a find and replace.
+    // Make sure that there will be no duplicate menu IDs after a find and replace.
 
     if (streq_any (type_txt, "menu", "pipe menu", NULL) && 
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ks.fr_in_columns[COL_MENU_ID]))) {
@@ -178,7 +178,7 @@ static gboolean validity_check (              GtkTreeModel *model,
             FOREACH_IN_LIST (ks.menu_ids, menu_ids_loop) {
                 if (G_UNLIKELY (STREQ (menu_ids_loop->data, new_menu_id_txt) && !STREQ (new_menu_id_txt, menu_id_txt))) {
                     g_autofree gchar *err_msg = g_strdup_printf (_("The menu ID <b>\"%1$s\"</b> won't be replaced with <b>\"%2$s\"</b>, "
-                                                                   "because this would create a double menu ID.\n\n"
+                                                                   "because this would create a duplicate menu ID.\n\n"
                                                                    "<b><span foreground='%3$s'>%4$s</span></b>"), 
                                                                  menu_id_txt, new_menu_id_txt, ks.red_hue, not_executed_str);
 
@@ -189,9 +189,9 @@ static gboolean validity_check (              GtkTreeModel *model,
             }
 
             /* 
-               Double menu IDs can also occur if for example for both menu IDs "menu1" and "menu2" the trailing numbers are removed.
+               Duplicate menu IDs can also occur if for example for both menu IDs "menu1" and "menu2" the trailing numbers are removed.
                All hypothetical new menu IDs are stored inside a list, and then sorted, because with that it is enough to compare a 
-               menu ID with the following one inside the list. If they are identical, there would be a double menu ID after the 
+               menu ID with the following one inside the list. If they are identical, there would be a duplicate menu ID after the 
                execution of the "find and replace" action.
             */
             if (*no_invalid_replacements) {
@@ -213,7 +213,7 @@ static gboolean validity_check (              GtkTreeModel *model,
                                 g_autofree gchar *err_msg = g_strdup_printf (_("A find and replace with these values "
                                                                                "would replace both menu IDs "
                                                                                "<b>\"%1$s\"</b> and <b>\"%2$s\"</b> with <b>\"%3$s\"</b>, "
-                                                                               "thus creating a double menu ID.\n\n"
+                                                                               "thus creating a duplicate menu ID.\n\n"
                                                                                "<b><span foreground='%4$s'>%5$s</span></b>"), 
                                                                              menu_IDs_before_and_after_pair1[1], 
                                                                              menu_IDs_before_and_after_pair2[1], 
